@@ -20,3 +20,17 @@ def available_metrics_for_slug(slug):
     )
 
     return execute_gql(query_str)['projectBySlug']['availableMetrics']
+
+
+def available_metric_for_slug_since(metric, slug):
+    query_str = ("""{{
+        getMetric(metric: \"{metric}\"){{
+            availableSince(slug: \"{slug}\")
+        }}
+    }}
+    """).format(
+        metric=metric,
+        slug=slug
+    )
+
+    return execute_gql(query_str)['getMetric']['availableSince']
